.. Packaging Scientific Python documentation master file, created by
   sphinx-quickstart on Thu Jun 28 12:35:56 2018.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

deepbiome Documentation
========================
   
.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :glob:

   introduction
   DeepBiome_usage_classification
   DeepBiome_usage_regression
   installation
   prerequisites
   usage
   example_with_one_input_file
   example_with_the_list_of_inputs
   release-history
   min_versions
   authors
   contributing